@@ -3,7 +3,6 @@
 # https://github.com/eea/odfpy
 import os
 import shutil
-# import thtools
 from jinjafy import jinjafy_comment
 from bs4 import BeautifulSoup
 import glob
@@ -253,10 +252,9 @@ def svg_edit_to_importable(svg_edit_file,verbose=False):
             with open(svg_fonts_layers[-1], 'bw') as f2:
                 f2.write(s2.encode("UTF-8"))
 
-            from thtools.slider.convert import svg2pdf
+            from slider.convert import svg2pdf
             svg2pdf(svg_fonts_layers[-1], fout=pdf_nofonts_layers[-1], crop=False, text_to_path=True, export_area_page=True)
             # cmd = ['inkscape', '-C', '-T', '--without-gui', '--file=%s'%svg_fonts_layers[-1], '--export-pdf=%s' % pdf_nofonts_layers[-1]]
-            # thtools.execute_command(cmd)
 
     if verbose:
         print("svg_edit_to_importable called. converted svg file\n  > %s\nto files:"%svg_edit_file)
@@ -322,14 +320,15 @@ def slidedeck_to_images(slide_deck_pdf, base_out_pattern, num_to_take=None):
     opat.replace("%i", '%d')
     cmd = f"pdftk {slide_deck_pdf} burst output {opat} compress"
     print("pdftk splitting into ", num_pages)
-    thtools.execute_command(cmd.split())
+
+    execute_command(cmd.split())
     outfiles = []
     slide_deck_split_pdf = [base_out_pattern[:-4] % (i + 1) + "_tmp.pdf" for i in range(num_pages)]
     for i, opdf in enumerate(slide_deck_split_pdf):
         print("convertion", i, opdf)
         ofile = base_out_pattern %(i+1)
         cmd = f"pdf2svg {opdf} {ofile}"
-        thtools.execute_command(cmd.split())
+        execute_command(cmd.split())
         b = os.path.getsize(ofile)
         # print(b)
         if b == 0:
@@ -357,7 +356,7 @@ def slidedeck_to_images_DEFUNCT(slide_deck_pdf, base_out_pattern, num_to_take=No
 
 def num_pages_in_pdf(pdf_file):
     cmd = ['pdftk', '%s' % pdf_file, 'dump_data']
-    ss = thtools.execute_command(cmd)[0].splitlines()
+    ss = execute_command(cmd)[0].splitlines()
     s = int([s for s in ss if 'NumberOfPages' in s].pop().split()[-1])
     return s
 
@@ -368,11 +367,11 @@ def slide_to_image(slide_deck_pdf, output, page_to_take=1, use_inkscape=True):
     slide_deck_split_pdf = output[:-4] + "_tmp.pdf"
     ext = output[-3:]
     if ext == "svg":
-        from thtools.slider.convert import pdf2svg
+        from slider.convert import pdf2svg
         pdf2svg(slide_deck_pdf, fout=output, page_no=page_to_take)
         # cmd = ['pdftk', '%s' % slide_deck_pdf, 'cat', '%i' % page_to_take, 'output', '%s' % slide_deck_split_pdf]
         # # page_to_take = 1
-        # thtools.execute_command(cmd)
+
         # if use_inkscape:
         #     cmd = ['inkscape', '-C', '--without-gui', '--file=%s' % slide_deck_split_pdf, '-l', '%s' % output]
         # else:
@@ -381,7 +380,7 @@ def slide_to_image(slide_deck_pdf, output, page_to_take=1, use_inkscape=True):
         if os.path.exists(output):
             os.remove(output)
         cmd = ("pdftocairo -png -f %i -l %i"% (page_to_take, page_to_take)).split(" ") + [slide_deck_pdf, output]
-        thtools.execute_command(cmd)
+        execute_command(cmd)
     if ext == "png":
         png_with_postfix = glob.glob(output + "-*.png")
         if not png_with_postfix:
